@@ -1,25 +1,25 @@
-(def ks-version "1.3.0")
-(def tk-version "1.3.1")
-
-(defproject puppetlabs/jruby-utils "0.2.1"
+(defproject puppetlabs/jruby-utils "0.4.0"
   :description "A library for working with JRuby"
   :url "https://github.com/puppetlabs/jruby-utils"
   :license {:name "Apache License, Version 2.0"
             :url "http://www.apache.org/licenses/LICENSE-2.0"}
 
+  :min-lein-version "2.7.1"
+  :parent-project {:coords [puppetlabs/clj-parent "0.1.3"]
+                   :inherit [:managed-dependencies]}
+
   :pedantic? :abort
 
   :source-paths ["src/clj"]
   :java-source-paths ["src/java"]
   :test-paths ["test/unit" "test/integration"]
 
-  :dependencies [[org.clojure/clojure "1.7.0"]
+  :dependencies [[org.clojure/clojure]
+                 [org.clojure/tools.logging]
 
-                 ;; begin version conflict resolution dependencies
-                 [cheshire "5.6.1"]
-                 [clj-time "0.11.0"]
-                 [org.slf4j/slf4j-api "1.7.13"]
-                 ;; end version conflict resolution dependencies
+                 [me.raynes/fs]
+                 [prismatic/schema]
+                 [slingshot]
 
                  [org.jruby/jruby-core "1.7.26"
                   :exclusions [com.github.jnr/jffi com.github.jnr/jnr-x86asm]]
@@ -34,16 +34,9 @@
                  ;; 'uberjar-exclusions' example toward the end of this file.
                  [org.jruby/jruby-stdlib "1.7.26"]
 
-
-                 [org.clojure/tools.logging "0.3.1"]
-                 [me.raynes/fs "1.4.6"]
-                 [prismatic/schema "1.1.0"]
-                 [slingshot "0.12.2"]
-
-
-                 [puppetlabs/trapperkeeper ~tk-version]
-                 [puppetlabs/kitchensink ~ks-version]
-                 [puppetlabs/ring-middleware "1.0.0"]]
+                 [puppetlabs/kitchensink]
+                 [puppetlabs/trapperkeeper]
+                 [puppetlabs/ring-middleware]]
 
   :deploy-repositories [["releases" {:url "https://clojars.org/repo"
                                      :username :env/clojars_jenkins_username
@@ -56,7 +49,9 @@
   ;; code that we have.
   :classifiers [["test" :testutils]]
 
-  :profiles {:dev {:dependencies  [[puppetlabs/kitchensink ~ks-version :classifier "test" :scope "test"]
-                                   [puppetlabs/trapperkeeper ~tk-version :classifier "test" :scope "test"]]}
+  :profiles {:dev {:dependencies  [[puppetlabs/kitchensink :classifier "test" :scope "test"]
+                                   [puppetlabs/trapperkeeper :classifier "test" :scope "test"]]}
              :testutils {:source-paths ^:replace ["test/unit" "test/integration"]}}
+
+  :plugins [[lein-parent "0.3.1"]]
   )
