@@ -40,6 +40,13 @@
   "Schema defining the supported values for the JRuby CompileMode setting."
   (apply schema/enum supported-jruby-compile-modes))
 
+(def supported-jruby-compat-versions
+  #{"1.9" "2.0"})
+
+(def SupportedJRubyCompatVersions
+  "Schema defining the supported compatability versions for the JRuby CompatVersions setting"
+  (apply schema/enum supported-jruby-compat-versions))
+
 (def LifecycleFns
   {:initialize-pool-instance IFn
    :cleanup IFn
@@ -53,7 +60,9 @@
 
     * :ruby-load-path - a vector of file paths, containing the locations of ruby source code.
 
-    * :gem-home - The location that JRuby gems are stored
+    * :gem-home - The location that JRuby gems will be installed
+
+    * :gem-path - The full path where JRuby should look for gems
 
     * :compile-mode - The value to use for JRuby's CompileMode setting.  Legal
         values are `:jit`, `:force`, and `:off`.  Defaults to `:off`.
@@ -65,7 +74,9 @@
         whitelisted and visible to any Ruby code."
   {:ruby-load-path [schema/Str]
    :gem-home schema/Str
+   :gem-path (schema/maybe schema/Str)
    :compile-mode SupportedJRubyCompileModes
+   :compat-version SupportedJRubyCompatVersions
    :borrow-timeout schema/Int
    :max-active-instances schema/Int
    :max-borrows-per-instance schema/Int
